"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var index_exports = {};
__export(index_exports, {
  BoxSlider: () => BoxSlider,
  CarouselSlider: () => CarouselSlider,
  CubeSlider: () => CubeSlider,
  FadeSlider: () => FadeSlider,
  TileSlider: () => TileSlider,
  createCarouselSlider: () => createCarouselSlider,
  createCubeSlider: () => createCubeSlider,
  createFadeSlider: () => createFadeSlider,
  createTileSlider: () => createTileSlider,
  default: () => box_slider_default,
  defaultOptions: () => defaultOptions2,
  getSliderElement: () => getSliderElement
});
module.exports = __toCommonJS(index_exports);

// src/utils.ts
function applyCss(el, styles) {
  Object.keys(styles).forEach((key) => el.style.setProperty(key, styles[key]));
}

// src/effects/fade-slider.ts
var FadeSlider = class {
  options;
  constructor(options) {
    this.options = {
      timingFunction: options?.timingFunction || "ease-in"
    };
  }
  initialize(el, slides, options) {
    if ("static inherit".includes(getComputedStyle(el).position)) {
      applyCss(el, { position: "relative" });
    }
    slides.forEach((slide, index) => {
      const active = index === options.startIndex;
      applyCss(slide, {
        height: "100%",
        left: "0",
        opacity: active ? "1" : "0",
        position: "absolute",
        top: "0",
        width: "100%",
        "z-index": active ? "2" : "1"
      });
    });
  }
  async transition({
    currentIndex,
    nextIndex,
    slides,
    speed
  }) {
    const currentSlide = slides[currentIndex];
    const nextSlide = slides[nextIndex];
    applyCss(currentSlide, { "z-index": "1" });
    applyCss(nextSlide, { "z-index": "2" });
    await Promise.all([
      currentSlide.animate(
        { opacity: [1, 0] },
        {
          duration: speed,
          easing: this.options.timingFunction,
          fill: "forwards"
        }
      ).finished,
      nextSlide.animate(
        { opacity: [0, 1] },
        {
          duration: speed,
          easing: this.options.timingFunction,
          fill: "forwards"
        }
      ).finished
    ]);
  }
  destroy(_, slides) {
    slides.forEach((slide) => {
      slide.getAnimations().forEach((animation) => animation.cancel());
    });
  }
};

// src/effects/carousel-slider.ts
var CarouselSlider = class {
  options;
  constructor(options) {
    this.options = {
      cover: options?.cover === true,
      timingFunction: options?.timingFunction || "ease-in-out"
    };
  }
  initialize(el, slides, options) {
    applyCss(el, {
      overflow: "hidden"
    });
    if ("static inherit".includes(getComputedStyle(el).position)) {
      applyCss(el, { position: "relative" });
    }
    slides.forEach((slide, index) => {
      const active = index === options.startIndex;
      applyCss(slide, {
        left: "0",
        position: "absolute",
        top: "0",
        transform: `translateX(${active ? 0 : slide.offsetWidth}px)`,
        "z-index": active ? "3" : "1"
      });
    });
  }
  async transition({
    currentIndex,
    isPrevious,
    nextIndex,
    slides,
    speed
  }) {
    const currentSlide = slides[currentIndex];
    const currentSlideWidth = currentSlide.offsetWidth;
    const nextSlide = slides[nextIndex];
    const nextSlideWidth = nextSlide.offsetWidth;
    applyCss(nextSlide, {
      "z-index": "3"
    });
    applyCss(currentSlide, {
      "z-index": "2"
    });
    const animateIn = nextSlide.animate(
      {
        transform: [
          `translateX(${isPrevious ? "-" + nextSlideWidth : nextSlideWidth}px)`,
          "translateX(0px)"
        ]
      },
      {
        duration: speed,
        easing: this.options.timingFunction,
        fill: "forwards"
      }
    );
    if (!this.options.cover) {
      await currentSlide.animate(
        {
          transform: [
            "translateX(0px)",
            `translateX(${isPrevious ? currentSlideWidth : "-" + currentSlideWidth}px)`
          ]
        },
        {
          duration: speed,
          easing: this.options.timingFunction,
          fill: "forwards"
        }
      ).finished;
    }
    await animateIn.finished;
    applyCss(currentSlide, {
      "z-index": "1"
    });
  }
  destroy(_, slides) {
    slides.forEach((slide) => {
      slide.getAnimations().forEach((animation) => animation.cancel());
    });
  }
};

// src/effects/cube-slider.ts
var CubeSlider = class {
  options;
  translateZ;
  constructor(options) {
    this.options = {
      direction: options?.direction || "horizontal",
      perspective: options?.perspective || 1e3
    };
  }
  initialize(el, slides, options, stateStore) {
    const width = el.offsetWidth;
    const height = el.offsetHeight;
    const perspective = `${this.options.perspective}px`;
    const viewport = el.parentElement;
    if (viewport == null) {
      throw new Error("Unable to locate viewport element for Cube slider");
    }
    this.translateZ = this.options.direction === "vertical" ? height / 2 : width / 2;
    stateStore.storeAttributes(viewport, ["style"]);
    slides.forEach(
      (slide) => applyCss(slide, {
        left: "0",
        position: "absolute",
        top: "0"
      })
    );
    applyCss(el, {
      left: "0",
      overflow: "visible",
      position: "absolute",
      top: "0"
    });
    if (!["absolute", "fixed", "relative"].includes(
      getComputedStyle(viewport).position
    )) {
      applyCss(viewport, { position: "relative" });
    }
    applyCss(viewport, {
      overflow: "visible",
      perspective
    });
    applyCss(slides[options.startIndex ?? 0], {
      transform: `${this.rotation(0)} translate3d(0,0,${this.translateZ}px)`
    });
    applyCss(el, {
      "transform-style": "preserve-3d",
      transform: `translate3d(0,0,-${this.translateZ}px)`
    });
  }
  async transition(settings) {
    const angle = settings.isPrevious ? 90 : -90;
    applyCss(settings.slides[settings.nextIndex], {
      transform: `${this.rotation(-angle)} translate3d(0,0,${this.translateZ}px)`
    });
    await settings.el.animate(
      {
        transform: `translate3d(0,0,-${this.translateZ}px) ${this.rotation(angle)}`
      },
      {
        duration: settings.speed
      }
    ).finished;
    settings.slides.forEach((s, index) => {
      if (index !== settings.nextIndex) {
        applyCss(s, { transform: "initial" });
      }
    });
    applyCss(settings.slides[settings.nextIndex], {
      transform: `${this.rotation(0)} translate3d(0,0,${this.translateZ}px)`
    });
    applyCss(settings.el, {
      transform: `translate3d(0,0,-${this.translateZ}px)`
    });
  }
  rotation(angle) {
    return `rotate3d(${this.options.direction === "vertical" ? "1, 0, 0" : "0, 1, 0"}, ${angle}deg)`;
  }
};

// src/effects/tile/tile-transition.ts
var TILE_CLASS = "bs-tile";
var FRONT_FACE_CLASS = "bs-tile-front";
var BACK_FACE_CLASS = "bs-tile-back";

// src/effects/tile/fade-transition.ts
var FadeTransition = class {
  createTile(tileSettings) {
    const tile = document.createElement("div");
    const front = document.createElement("div");
    const back = document.createElement("div");
    const faces = [front, back];
    tile.classList.add(tileSettings.tileClass);
    applyCss(tile, {
      height: `${tileSettings.height}px`,
      left: `${tileSettings.fromLeft}px`,
      overflow: "hidden",
      position: "absolute",
      top: `${tileSettings.fromTop}px`,
      width: `${tileSettings.width}px`
    });
    faces.forEach((face) => {
      applyCss(face, {
        height: `${tileSettings.boxHeight}px`,
        left: `-${tileSettings.fromLeft}px`,
        position: "absolute",
        top: `-${tileSettings.fromTop}px`,
        width: `${tileSettings.boxWidth}px`
      });
    });
    applyCss(back, { opacity: "0" });
    front.classList.add(tileSettings.frontClass);
    tile.append(front);
    back.classList.add(tileSettings.backClass);
    tile.append(back);
    return tile;
  }
  async transition({ tile, nextFace, delay, duration }) {
    const front = tile.querySelector(`.${FRONT_FACE_CLASS}`);
    const back = tile.querySelector(`.${BACK_FACE_CLASS}`);
    const frontAnimation = front.animate(
      { opacity: nextFace === "front" ? 1 : 0 },
      { duration, fill: "forwards", delay }
    );
    const backAnimation = back.animate(
      { opacity: nextFace === "front" ? 0 : 1 },
      { duration, fill: "forwards", delay }
    );
    await Promise.all([frontAnimation.finished, backAnimation.finished]);
  }
  setTileFace(slide, tileFace) {
    const clone = slide.cloneNode(true);
    clone.style.removeProperty("visibility");
    tileFace.replaceChildren(clone);
  }
};
var fade_transition_default = FadeTransition;

// src/effects/tile/flip-transition.ts
var FlipTransition = class {
  createTile(tileSettings) {
    const tileHolder = document.createElement("div");
    const tile = document.createElement("div");
    const front = document.createElement("div");
    const frontFace = document.createElement("div");
    const back = document.createElement("div");
    const backFace = document.createElement("div");
    const faces = [frontFace, backFace];
    applyCss(tileHolder, {
      height: `${tileSettings.height}px`,
      left: `${tileSettings.fromLeft}px`,
      perspective: "300px",
      position: "absolute",
      top: `${tileSettings.fromTop}px`,
      width: `${tileSettings.width}px`,
      "z-index": `${tileSettings.zIndex}`
    });
    tile.classList.add(tileSettings.tileClass);
    applyCss(tile, {
      height: "100%",
      position: "relative",
      "transform-style": "preserve-3d",
      width: "100%"
    });
    tileHolder.append(tile);
    faces.forEach(
      (face) => applyCss(face, {
        height: `${tileSettings.boxHeight}px`,
        left: `-${tileSettings.fromLeft}px`,
        position: "absolute",
        top: `-${tileSettings.fromTop}px`,
        width: `${tileSettings.boxWidth}px`
      })
    );
    applyCss(front, {
      "backface-visibility": "hidden",
      inset: "0",
      overflow: "hidden",
      position: "absolute",
      "z-index": "1"
    });
    applyCss(back, {
      "backface-visibility": "hidden",
      inset: "0",
      overflow: "hidden",
      position: "absolute",
      transform: "rotateY(180deg)",
      "z-index": "2"
    });
    front.append(frontFace);
    front.classList.add(tileSettings.frontClass);
    tile.append(front);
    back.append(backFace);
    back.classList.add(tileSettings.backClass);
    tile.append(back);
    return tileHolder;
  }
  async transition({ tile, nextFace, delay, duration }) {
    await tile.animate(
      {
        transform: [
          `rotateY(${nextFace === "back" ? 0 : 180}deg)`,
          `rotateY(${nextFace === "back" ? 180 : 0}deg)`
        ]
      },
      {
        delay,
        duration,
        fill: "forwards"
      }
    ).finished;
  }
  setTileFace(slide, tileFace) {
    const clone = slide.cloneNode(true);
    clone.style.removeProperty("visibility");
    tileFace.firstElementChild.replaceChildren(clone);
  }
};
var flip_transition_default = FlipTransition;

// src/effects/tile/tile-slider.ts
var defaultOptions = {
  rowOffset: 50,
  rows: 8,
  tileEffect: "flip"
};
var TileSlider = class {
  options;
  _tileWrapper;
  tileTransition;
  grid;
  activeFace;
  get tileWrapper() {
    if (this._tileWrapper === void 0) {
      throw new Error("TileWrapper is undefined");
    }
    return this._tileWrapper;
  }
  constructor(options) {
    this.options = { ...defaultOptions, ...options };
    this.activeFace = "front";
    this.tileTransition = this.options.tileEffect === "fade" ? new fade_transition_default() : new flip_transition_default();
  }
  initialize(el, slides, options) {
    const slide = slides[options.startIndex || 0];
    const fragment = document.createDocumentFragment();
    this.grid = this.calculateGrid(el);
    if (this._tileWrapper) {
      this.destroy();
    }
    const tileWrapper = document.createElement("div");
    tileWrapper.setAttribute("aria-hidden", "true");
    tileWrapper.dataset.bsElement = "true";
    el.append(tileWrapper);
    this._tileWrapper = tileWrapper;
    if (!"fixed absolute relative".includes(getComputedStyle(el).position)) {
      applyCss(el, { position: "relative" });
    }
    applyCss(this.tileWrapper, {
      position: "absolute",
      inset: "0",
      display: "none"
    });
    const totalTiles = this.grid.rows * this.grid.cols;
    for (let i = 0; i < this.grid.rows; ++i) {
      const fromTop = i * this.grid.tileHeight;
      for (let j = 0; j < this.grid.cols; ++j) {
        const tile = this.tileTransition.createTile({
          backClass: `${TILE_CLASS}-back`,
          boxWidth: this.grid.width,
          boxHeight: this.grid.height,
          fromTop,
          fromLeft: j * this.grid.tileWidth,
          frontClass: `${TILE_CLASS}-front`,
          height: this.grid.tileHeight,
          speed: (options.speed - this.options.rowOffset * (this.grid.rows - 1)) / this.grid.cols,
          tileClass: TILE_CLASS,
          width: this.grid.tileWidth,
          zIndex: totalTiles - (i + j)
        });
        fragment.append(tile);
        this.tileTransition.setTileFace(
          slide,
          tile.querySelector(`.${FRONT_FACE_CLASS}`)
        );
      }
    }
    slides.forEach(
      (s, index) => applyCss(s, {
        position: "absolute",
        visibility: index === options.startIndex ? "visible" : "hidden"
      })
    );
    this.tileWrapper.append(fragment);
  }
  async transition(settings) {
    const tiles = this.tileWrapper.querySelectorAll(`.${TILE_CLASS}`);
    const tileDuration = (settings.speed - this.options.rowOffset * (this.grid.rows - 1)) / this.grid.cols;
    const nextFace = this.activeFace === "front" ? "back" : "front";
    this.tileWrapper.style.setProperty("display", "block");
    settings.slides[settings.currentIndex].style.setProperty(
      "visibility",
      "hidden"
    );
    this.tileWrapper.querySelectorAll(
      `.${nextFace === "front" ? FRONT_FACE_CLASS : BACK_FACE_CLASS}`
    ).forEach(
      (tile) => this.tileTransition.setTileFace(
        settings.slides[settings.nextIndex],
        tile
      )
    );
    for (let i = 0; i < this.grid.rows; i++) {
      for (let j = 0; j < this.grid.cols; j++) {
        const index = i * this.grid.cols + j;
        const tile = tiles[index];
        const transition = this.tileTransition.transition({
          delay: i * this.options.rowOffset + j * tileDuration,
          duration: tileDuration,
          nextFace,
          tile
        });
        if (index === tiles.length - 1) {
          await transition;
          this.activeFace = nextFace;
          this.tileWrapper.style.setProperty("display", "none");
          settings.slides[settings.nextIndex].style.setProperty(
            "visibility",
            "visible"
          );
        }
      }
    }
  }
  destroy() {
    this.tileWrapper.remove();
    delete this._tileWrapper;
  }
  calculateGrid(el) {
    const { width: elWidth, height: elHeight } = getComputedStyle(el);
    const height = Number.parseInt(elHeight, 10) ?? el.offsetHeight;
    const width = Number.parseInt(elWidth, 10) ?? el.offsetWidth;
    const rows = this.options.rows;
    const tileHeight = Math.ceil(height / rows);
    const cols = Math.floor(el.offsetWidth / tileHeight);
    const tileWidth = Math.ceil(width / cols);
    return { cols, height, rows, tileHeight, tileWidth, width };
  }
};

// src/state-store.ts
var StateStore = class {
  elementStore;
  constructor() {
    this.elementStore = /* @__PURE__ */ new Map();
  }
  storeAttributes(elements, attributes) {
    const elems = Array.isArray(elements) ? elements : [elements];
    elems.forEach((el) => {
      const store = this.elementStore.get(el) ?? {};
      attributes.forEach(
        (attr) => store[attr] = el.getAttribute(attr)
      );
      this.elementStore.set(el, store);
    });
  }
  revert() {
    for (const [el, attributes] of this.elementStore.entries()) {
      Object.keys(attributes).forEach((attribute) => {
        const cachedValue = attributes[attribute];
        if (cachedValue === null || cachedValue === "") {
          el.removeAttribute(attribute);
        } else if (cachedValue !== null) {
          el.setAttribute(attribute, cachedValue);
        }
      });
    }
    this.elementStore.clear();
  }
};

// src/responder.ts
var boxSliders = [];
var resizeObserver;
if (typeof ResizeObserver !== "undefined") {
  resizeObserver = new ResizeObserver((sliderElements) => {
    sliderElements.forEach(
      (sliderEl) => boxSliders.find((bs) => bs.el === sliderEl.target)?.reset()
    );
  });
}
var responder = {
  add(boxSlider) {
    boxSliders.push(boxSlider);
    resizeObserver?.observe(boxSlider.el);
  },
  remove(boxSlider) {
    resizeObserver?.unobserve(boxSlider.el);
    boxSliders = boxSliders.filter((b) => b !== boxSlider);
  }
};

// src/transition-queue.ts
var createQueue = () => {
  let next = null;
  function run() {
    const fn = next;
    fn?.().then(() => {
      if (fn === next) {
        next = null;
      } else {
        run();
      }
    });
  }
  return {
    push(fn) {
      const runNow = next === null;
      next = fn;
      if (runNow) {
        run();
      }
    },
    clear() {
      next = null;
    }
  };
};

// src/box-slider.ts
function safeMatchMedia(query) {
  return typeof matchMedia !== "undefined" && matchMedia(query).matches;
}
var defaultOptions2 = Object.freeze({
  autoScroll: !safeMatchMedia("(prefers-reduced-motion: reduce)"),
  loop: true,
  pauseOnHover: safeMatchMedia("(pointer: fine)"),
  speed: 800,
  startIndex: 0,
  swipe: true,
  swipeTolerance: 30,
  timeout: 5e3
});
var BoxSlider = class {
  _activeIndex;
  _el;
  _effect;
  _stateStore;
  options;
  slides;
  autoScrollTimer;
  eventListeners;
  elListeners;
  isDestroyed;
  transitionQueue;
  /**
   * The currently active slide index
   */
  get activeIndex() {
    return this._activeIndex;
  }
  /**
   * The slider element
   */
  get el() {
    if (this._el === void 0) {
      throw new Error("Slider element is undefined");
    }
    return this._el;
  }
  /**
   * The number of slides in the slider
   */
  get length() {
    return this.slides.length;
  }
  /**
   * Return the value of a option at key
   */
  getOption(key) {
    return this.options[key];
  }
  get stateStore() {
    if (this._stateStore === void 0) {
      throw new Error(
        "State store is undefined, are you trying to interact with a destroyed slider?"
      );
    }
    return this._stateStore;
  }
  get effect() {
    if (this._effect === void 0) {
      throw new Error(
        "Slide effect is undefined, are you trying to interact with a destroyed slider?"
      );
    }
    return this._effect;
  }
  constructor(el, effect, options) {
    this._el = el;
    this._stateStore = new StateStore();
    this.transitionQueue = createQueue();
    this.slides = [];
    this.eventListeners = {};
    this.elListeners = {};
    this.isDestroyed = false;
    this.options = {
      ...defaultOptions2,
      ...options
    };
    this._activeIndex = this.options.startIndex;
    this.init(effect);
    this.applyEventListeners();
    responder.add(this);
  }
  /**
   * Reset the slider with optional new settings and effect
   */
  reset(options, effect) {
    this.stopAutoScroll();
    if (typeof this.effect.destroy === "function") {
      this.effect.destroy(this.el, this.slides);
    }
    this.stateStore.revert();
    this.options = {
      ...this.options,
      ...options
    };
    if (options?.startIndex !== void 0 && !Number.isNaN(options.startIndex)) {
      this._activeIndex = options.startIndex;
    }
    this.init(effect || this.effect);
    this.emit("reset");
  }
  /**
   * Show the next slide. If the slider is at the last slide and loop is disabled
   * then the slider will not advance back to the first slide.
   */
  next() {
    const isLastSlide = this.activeIndex === this.slides.length - 1;
    if (isLastSlide && !this.options.loop) {
      return Promise.resolve();
    }
    return this.skipTo(isLastSlide ? 0 : this.activeIndex + 1, false);
  }
  /**
   * Show the previous slide. If the slider is at the first slide and loop is disabled
   * then the slider will not advance back to the last slide.
   */
  prev() {
    const isFirstSlide = this.activeIndex === 0;
    if (isFirstSlide && !this.options.loop) {
      return Promise.resolve();
    }
    return this.skipTo(
      isFirstSlide ? this.slides.length - 1 : this.activeIndex - 1,
      true
    );
  }
  /**
   * Skip to a specific slide index
   */
  skipTo(nextIndex, backwards) {
    return new Promise((resolve) => {
      this.transitionQueue.push(async () => {
        await this.transitionTo(
          nextIndex,
          backwards === void 0 ? nextIndex < this.activeIndex : backwards
        );
        resolve();
      });
    });
  }
  /**
   * Pause the slider from auto scrolling
   */
  pause() {
    this.options.autoScroll = false;
    if (this.autoScrollTimer) {
      this.stopAutoScroll();
      this.emit("pause");
    }
    return this;
  }
  /**
   * Start the slider auto scrolling
   */
  play() {
    this.options.autoScroll = true;
    this.setAutoScroll();
    this.emit("play");
    return this;
  }
  /**
   * Add an event listener for a slider event
   */
  addEventListener(ev, callback) {
    if (!Array.isArray(this.eventListeners[ev])) {
      this.eventListeners[ev] = [];
    }
    this.eventListeners[ev].push(callback);
    return this;
  }
  /**
   * Remove an event listener for a slider event. The listener
   * must be the original function passed to addEventListener
   */
  removeEventListener(ev, callback) {
    const listeners = this.eventListeners[ev]?.filter(
      (cb) => cb !== callback
    );
    this.eventListeners[ev] = listeners;
    return this;
  }
  /**
   * Destroy the slider, remove all event listeners and attributes
   */
  destroy() {
    this.isDestroyed = true;
    this.stopAutoScroll();
    if (this.effect.destroy) {
      this.effect.destroy(this.el, this.slides);
    }
    this.stateStore.revert();
    this.transitionQueue.clear();
    responder.remove(this);
    this.emit("destroy");
    this.eventListeners = {};
    Object.entries(this.elListeners).forEach(
      ([ev, listeners]) => listeners.forEach(
        (listener) => this.el.removeEventListener(ev, listener)
      )
    );
    this.elListeners = {};
    delete this._el;
    delete this._stateStore;
    delete this._effect;
    this.slides.length = 0;
  }
  init(effect) {
    this._effect = effect;
    this.slides = this.getSlides();
    this.stateStore.storeAttributes([this.el, ...this.slides], ["style"]);
    if (this.activeIndex >= this.slides.length) {
      this._activeIndex = 0;
    }
    this.effect.initialize(
      this.el,
      this.slides,
      {
        ...this.options,
        startIndex: this.activeIndex
      },
      this.stateStore
    );
    this.addAriaAttributes();
    if (this.options.autoScroll) {
      this.setAutoScroll();
    }
  }
  addAriaAttributes() {
    this.stateStore.storeAttributes(
      [this.el, ...this.slides],
      ["aria-hidden", "aria-live", "aria-roledescription", "role"]
    );
    this.el.setAttribute("aria-atomic", "false");
    this.el.setAttribute("aria-live", "polite");
    if (!this.el.hasAttribute("role")) {
      this.el.setAttribute("role", "region");
    }
    this.slides.forEach((slide, index) => {
      if (!slide.hasAttribute("role")) {
        slide.setAttribute("role", "group");
      }
      if (!slide.hasAttribute("aria-roledescription")) {
        slide.setAttribute("aria-roledescription", "slide");
      }
      slide.setAttribute(
        "aria-hidden",
        index === this.activeIndex ? "false" : "true"
      );
    });
  }
  getSlides() {
    return [...this.el.children].filter(
      (child) => child instanceof HTMLElement
    );
  }
  async transitionTo(nextIndex, backwards) {
    this.stopAutoScroll();
    if (this.isDestroyed || nextIndex === this.activeIndex || nextIndex < 0 || nextIndex >= this.slides.length) {
      return;
    }
    const settings = {
      el: this.el,
      slides: this.slides,
      speed: this.options.speed,
      currentIndex: this.activeIndex,
      isPrevious: backwards,
      nextIndex
    };
    this._activeIndex = nextIndex;
    this.emit("before", {
      currentIndex: settings.currentIndex,
      nextIndex: settings.nextIndex,
      speed: settings.speed
    });
    try {
      await (this.effect.transition(settings) ?? Promise.resolve());
    } catch {
      return;
    }
    if (this.isDestroyed) {
      return;
    }
    if (this.options.autoScroll) {
      this.setAutoScroll();
    }
    this.slides[settings.currentIndex].setAttribute("aria-hidden", "true");
    this.slides[settings.nextIndex].setAttribute("aria-hidden", "false");
    this.emit("after");
  }
  stopAutoScroll() {
    globalThis.clearTimeout(this.autoScrollTimer);
  }
  emit(ev, payload) {
    const handlers = this.eventListeners[ev];
    if (ev === "destroy") {
      const destroyHandlers = handlers;
      destroyHandlers?.forEach((cb) => cb());
    } else {
      handlers?.forEach(
        (cb) => cb({
          currentIndex: this.activeIndex,
          speed: this.options.speed,
          ...payload
        })
      );
    }
  }
  setAutoScroll() {
    this.stopAutoScroll();
    globalThis.requestAnimationFrame(() => {
      if (!this._el) {
        return;
      }
      this.el.setAttribute("aria-live", "off");
      this.autoScrollTimer = globalThis.setTimeout(
        () => this.next(),
        this.options.timeout
      );
    });
  }
  addElListener(ev, handler) {
    this.el.addEventListener(ev, handler, { passive: true });
    this.elListeners[ev] = this.elListeners[ev] || [];
    this.elListeners[ev].push(handler);
  }
  applyEventListeners() {
    this.addElListener("pointerenter", () => {
      if (this.options.autoScroll && this.options.pauseOnHover) {
        this.pause();
      }
    });
    this.addElListener("pointerleave", () => {
      if (this.options.autoScroll && this.options.pauseOnHover) {
        this.play();
      }
    });
    if (this.options.swipe) {
      this.addSwipeNavigation();
    }
  }
  addSwipeNavigation() {
    let startX = 0;
    this.addElListener("touchstart", (ev) => {
      startX = ev.changedTouches[0].screenX;
    });
    this.addElListener("touchend", (ev) => {
      const distanceX = ev.changedTouches[0].screenX - startX;
      if (Math.abs(distanceX) >= this.options.swipeTolerance) {
        if (distanceX > 0) {
          this.prev();
        } else {
          this.next();
        }
      }
    });
  }
};
var box_slider_default = BoxSlider;

// src/index.ts
function getSliderElement(el) {
  if (typeof el === "string") {
    const queryEl = document.querySelector(el);
    if (queryEl === null) {
      throw new Error(`Slider element not found: ${el}`);
    }
    return queryEl;
  }
  return el;
}
function createCarouselSlider(el, options = {}) {
  const { timingFunction, cover, ...boxSliderOptions } = options;
  return new box_slider_default(
    getSliderElement(el),
    new CarouselSlider({ timingFunction, cover }),
    boxSliderOptions
  );
}
function createCubeSlider(el, options = {}) {
  const { direction, perspective, ...boxSliderOptions } = options;
  return new box_slider_default(
    getSliderElement(el),
    new CubeSlider({ direction, perspective }),
    boxSliderOptions
  );
}
function createFadeSlider(el, options = {}) {
  const { timingFunction, ...boxSliderOptions } = options;
  return new box_slider_default(
    getSliderElement(el),
    new FadeSlider({ timingFunction }),
    boxSliderOptions
  );
}
function createTileSlider(el, options = {}) {
  const { rowOffset, rows, tileEffect, ...boxSliderOptions } = options;
  return new box_slider_default(
    getSliderElement(el),
    new TileSlider({ rowOffset, rows, tileEffect }),
    boxSliderOptions
  );
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  BoxSlider,
  CarouselSlider,
  CubeSlider,
  FadeSlider,
  TileSlider,
  createCarouselSlider,
  createCubeSlider,
  createFadeSlider,
  createTileSlider,
  defaultOptions,
  getSliderElement
});
