// src/utils.ts
function applyCss(el, styles) {
  Object.keys(styles).forEach((key) => el.style.setProperty(key, styles[key]));
}

// src/effects/fade-slider.ts
var FadeSlider = class {
  options;
  constructor(options) {
    this.options = {
      timingFunction: options?.timingFunction || "ease-in"
    };
  }
  initialize(el, slides, options) {
    if ("static inherit".includes(getComputedStyle(el).position)) {
      applyCss(el, { position: "relative" });
    }
    slides.forEach((slide, index) => {
      const active = index === options.startIndex;
      applyCss(slide, {
        height: "100%",
        left: "0",
        opacity: active ? "1" : "0",
        position: "absolute",
        top: "0",
        width: "100%",
        "z-index": active ? "2" : "1"
      });
    });
  }
  async transition({
    currentIndex,
    nextIndex,
    slides,
    speed
  }) {
    const currentSlide = slides[currentIndex];
    const nextSlide = slides[nextIndex];
    applyCss(currentSlide, { "z-index": "1" });
    applyCss(nextSlide, { "z-index": "2" });
    await Promise.all([
      currentSlide.animate(
        { opacity: [1, 0] },
        {
          duration: speed,
          easing: this.options.timingFunction,
          fill: "forwards"
        }
      ).finished,
      nextSlide.animate(
        { opacity: [0, 1] },
        {
          duration: speed,
          easing: this.options.timingFunction,
          fill: "forwards"
        }
      ).finished
    ]);
  }
  destroy(_, slides) {
    slides.forEach((slide) => {
      slide.getAnimations().forEach((animation) => animation.cancel());
    });
  }
};
export {
  FadeSlider as default
};
