import type { BoxSliderOptions, Effect, SliderEventListenerMap, SliderEventType } from './types';
export declare const defaultOptions: BoxSliderOptions;
export declare class BoxSlider {
    private _activeIndex;
    private _el?;
    private _effect?;
    private _stateStore?;
    private options;
    private slides;
    private autoScrollTimer?;
    private eventListeners;
    private elListeners;
    private isDestroyed;
    private transitionQueue;
    /**
     * The currently active slide index
     */
    get activeIndex(): number;
    /**
     * The slider element
     */
    get el(): HTMLElement;
    /**
     * The number of slides in the slider
     */
    get length(): number;
    /**
     * Return the value of a option at key
     */
    getOption<T extends keyof BoxSliderOptions>(key: T): BoxSliderOptions[T];
    private get stateStore();
    private get effect();
    constructor(el: HTMLElement, effect: Effect, options?: Partial<BoxSliderOptions>);
    /**
     * Reset the slider with optional new settings and effect
     */
    reset(options?: Partial<BoxSliderOptions>, effect?: Effect): void;
    /**
     * Show the next slide. If the slider is at the last slide and loop is disabled
     * then the slider will not advance back to the first slide.
     */
    next(): Promise<void>;
    /**
     * Show the previous slide. If the slider is at the first slide and loop is disabled
     * then the slider will not advance back to the last slide.
     */
    prev(): Promise<void>;
    /**
     * Skip to a specific slide index
     */
    skipTo(nextIndex: number, backwards?: boolean): Promise<void>;
    /**
     * Pause the slider from auto scrolling
     */
    pause(): BoxSlider;
    /**
     * Start the slider auto scrolling
     */
    play(): BoxSlider;
    /**
     * Add an event listener for a slider event
     */
    addEventListener<T extends SliderEventType>(ev: T, callback: SliderEventListenerMap[T]): BoxSlider;
    /**
     * Remove an event listener for a slider event. The listener
     * must be the original function passed to addEventListener
     */
    removeEventListener<T extends SliderEventType>(ev: T, callback: SliderEventListenerMap[T]): BoxSlider;
    /**
     * Destroy the slider, remove all event listeners and attributes
     */
    destroy(): void;
    private init;
    private addAriaAttributes;
    private getSlides;
    private transitionTo;
    private stopAutoScroll;
    private emit;
    private setAutoScroll;
    private addElListener;
    private applyEventListeners;
    private addSwipeNavigation;
}
export default BoxSlider;
